<div class="mf-onboard-step-2-inner">
    <div class="mf-onboard-step-2-content">
        <div class="mf-onboard-main-header">
            <h1 class="mf-onboard-main-header--title"><strong><?php echo esc_html__('The Best Form Builder Plugin for Elementor.', 'metform'); ?></strong></h1>
            <p class="mf-onboard-main-header--description"><?php echo esc_html__('Sign Up to Join a Big Community of Marketers, Developers, and Think Tankers', 'metform'); ?></p>
        </div>
        <div class="mf-onboard-signup">
            <label for="signup"><i class="icon xs-onboard-mail"></i></label>
            <input name="settings[newsletter_email]" id="signup" type="email" placeholder="Enter your email address">
        </div>
        <p class="mf-onboard-signup--helptext"><?php echo esc_html__('Submit Your Best Email.', 'metform'); ?> <span><?php echo esc_html('(We Never Spam)', 'metform'); ?></span></p>
    </div>


    <div class="mf-onboard-pagination">
        <a class="mf-onboard-btn mf-onboard-pagi-btn prev" href="#"><i class="xs-onboard-arrow-left"></i><?php echo esc_html__('Back', 'metform'); ?></a>
        <a class="mf-onboard-btn mf-onboard-pagi-btn next" href="#"><?php echo esc_html__('Next Step', 'metform'); ?></a>
    </div>

    <div class="mf-onboard-shapes">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-01.png" alt="" class="shape-01">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-02.png" alt="" class="shape-02">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-03.png" alt="" class="shape-03">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-04.png" alt="" class="shape-04">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-05.png" alt="" class="shape-05">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-06.png" alt="" class="shape-06">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-07.png" alt="" class="shape-07">
        <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-09.png" alt="" class="shape-09">
    </div>
</div>