<div class="mf-onboard-main-header">
    <img class="mf-onboard-main-header--thumb" src="<?php echo esc_url(self::get_url()); ?>assets/images/congrats-shape.png" alt="">
    <h1 class="mf-onboard-main-header--title"><strong><?php echo esc_html__('Congratulations!', 'metform'); ?></strong></h1>
    <p class="mf-onboard-main-header--description"><?php echo esc_html__('Let’s dive into developing your website with the world’s best addons for Elementor.', 'metform'); ?></p>
    <button class="mf-onboard-btn mf-admin-settings-form-submit" type="submit"><div class="mf-spinner"></div> <?php echo esc_html__('Save Changes', 'metform'); ?></button>
</div>
<div class="mf-onboard-shapes">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-04.png" alt="" class="shape-04">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-07.png" alt="" class="shape-07">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-15.png" alt="" class="shape-15">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-21.png" alt="" class="shape-21">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-22.png" alt="" class="shape-22">
</div>