<div class="mf-onboard-main-header">
    <h1 class="mf-onboard-main-header--title"> 
   
            <?php echo esc_html__('Upgrade within the next','metform')?> <br/>
            <strong><?php echo esc_html__('2 hours', 'metform') ?></strong>
            <?php echo esc_html__(' and get a ','metform')?>
            <strong><?php echo esc_html__('40% Discount', 'metform') ?></strong>
        
    </h1>
</div>

<div class="mf-onboard-pro-features">
    <h2><?php echo esc_html__('Metform', 'metform'); ?> <span><?php echo esc_html__('PRO', 'metform'); ?></span></h2>

    <ul class="mf-onboard-modules">
        <li><img src="<?php echo esc_url(self::get_url()); ?>assets/images/features/module-icon-01.png" alt=""><span><?php echo esc_html__('Free Premium’ Features', 'metform'); ?></span></li>
        <li><img src="<?php echo esc_url(self::get_url()); ?>assets/images/features/module-icon-02.png" alt=""><span><?php echo esc_html__('Smart Conditional Logic', 'metform'); ?></span></li>
        <li><img src="<?php echo esc_url(self::get_url()); ?>assets/images/features/module-icon-03.png" alt=""><span><?php echo esc_html__('Required Fields Validation', 'metform'); ?></span></li>
        <li><img src="<?php echo esc_url(self::get_url()); ?>assets/images/features/module-icon-04.png" alt=""><span><?php echo esc_html__('Popular CRM Integrations', 'metform'); ?></span></li>
        <li><img src="<?php echo esc_url(self::get_url()); ?>assets/images/features/module-icon-05.png" alt=""><span><?php echo esc_html__('Data Within Dashboard', 'metform'); ?></span></li>
    </ul>
    <ul class="mf-onboard-module-meta">
        <li><i class="xs-onboard-check"></i> <?php echo esc_html__('15+ Third-Party API Integrations', 'metform'); ?></li>
        <li><i class="xs-onboard-check"></i> <?php echo esc_html__('35+ Form Input Widgets', 'metform'); ?></li>
        <li><i class="xs-onboard-check"></i> <?php echo esc_html__('10+ Advanced Features for Customizations', 'metform'); ?></li>
    </ul>

    <a href="https://wpmet.com/plugin/metform/pricing/?promo=onboard-coupon" target="_blank" class="attr-btn attr-btn-primary mf-pro-btn"><?php echo esc_html__('Explore PRO', 'metform'); ?> <i class="icon icon-arrow-right"></i></a>
</div>

<div class="mf-onboard-pagination">
    <a class="mf-onboard-btn mf-onboard-pagi-btn prev" href="#"><i class="xs-onboard-arrow-left"></i><?php echo esc_html__('Back', 'metform'); ?></a>
    <a class="mf-onboard-btn mf-onboard-pagi-btn next" href="#"><?php echo esc_html__('Next Step', 'metform'); ?></a>
</div>

<div class="mf-onboard-shapes">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-14.png" alt="" class="shape-14">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-15.png" alt="" class="shape-15">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-18.png" alt="" class="shape-18">
    <img src="<?php echo esc_url(self::get_url()); ?>assets/images/shape-19.png" alt="" class="shape-19">
</div>